# Security Policy

## Supported Versions

Currently supported versions are 3.0.0 and 1.3.1 . Please use 3.0.0 as default since 1.3.1 support is no longer planned.

| Version | Supported          |
| ------- | ------------------ |
| 3.0.0   | :white_check_mark: |
| 2.0.x   | :x:                |
| 1.3.1   | :white_check_mark: |

## Reporting a Vulnerability

Please report all vulnerabilities through [GitHub Issue Tracker](https://github.com/melexis/warnings-plugin/issues).
Make sure you include ways to replicate it and, if possible, propose a Pull Request with a potential fix.
